@@ -25,5 +25,4 @@ class skyway:
         for i2 in echofinder:
             print(echofinder[echofinder.index(i2)].split('"')[1])
 
-yigit = skyway()
-yigit.read("./skyway/skyway/", "main.sky")
+
